==> bjy_liveui_flutter-3.24.1.tar.gz: android/src/main/kotlin/com/baijiayun/flutter/bjy_liveui_flutter/LiveUiModule.kt <==
package com.baijiayun.flutter.bjy_liveui_flutter

import android.content.Context
import com.baijiayun.groupclassui.InteractiveClassUI
import com.baijiayun.live.ui.LiveSDKWithUI
import com.baijiayun.livecore.context.LPConstants
import com.baijiayun.livecore.models.LPJoinCodeEnterRoomModel
import com.baijiayun.livecore.models.LPSignEnterRoomModel
import com.baijiayun.livecore.models.LPUserModel
import com.baijiayun.liveshow.ui.LiveShowSDKWithUI
import com.baijiayun.liveuiee.LiveEESDKWithUI

/**
 * 三分屏模板-参加码加入
 * @param code 参加码
 * @param userName 用户名
 */
fun startLiveTripleTemplateWithCode(context: Context, code: String, userName: String) {
    LiveSDKWithUI.enterRoom(context, LPJoinCodeEnterRoomModel(code, userName))
}

/**
 * 三分屏模板-签名加入
 * @param roomId 房间号
 * @param sign   签名
 * @param userInfo 用户信息
 */
fun startLiveTripleTemplateWithSign(
    context: Context,
    roomId: String,
    sign: String,
    userInfo: HashMap<String, Any>
) {
    val lpSignEnterRoomModel = LPSignEnterRoomModel(roomId.toLong(), parseUserModel(userInfo), sign)
    LiveSDKWithUI.enterRoom(context, lpSignEnterRoomModel)
}

/**
 * 竖屏模板-参加码加入
 * @param code
 * @param userName
 */
fun startLiveEETemplateWithCode(context: Context, code: String, userName: String) {
    LiveEESDKWithUI.enterRoom(context, LPJoinCodeEnterRoomModel(code, userName))
}

/**
 * 竖屏模板-签名加入
 * @param roomId
 * @param sign
 * @param userInfo
 */
fun startLiveEETemplateWithSign(
    context: Context,
    roomId: String,
    sign: String,
    userInfo: HashMap<String, Any>
) {
    val lpSignEnterRoomModel = LPSignEnterRoomModel(roomId.toLong(), parseUserModel(userInfo), sign)
    LiveEESDKWithUI.enterRoom(context, lpSignEnterRoomModel)
}

/**
 * 直播带货模板-参加码加入
 * @param code
 * @param userName
 */
fun startLiveSellTemplateWithCode(context: Context, code: String, userName: String) {
    LiveShowSDKWithUI.enterRoom(context, LPJoinCodeEnterRoomModel(code, userName))
}

/**
 * 直播带货模板-签名加入
 * @param roomId
 * @param sign
 * @param userInfo
 */
fun startLiveSellTemplateWithSign(
    context: Context,
    roomId: String,
    sign: String,
    userInfo: HashMap<String, Any>
) {
    val lpSignEnterRoomModel = LPSignEnterRoomModel(roomId.toLong(), parseUserModel(userInfo), sign)
    LiveShowSDKWithUI.enterRoom(context, lpSignEnterRoomModel)
}

/**
 * 专业小班课模板-参加码加入
 * @param code
 * @param userName
 */
fun startProfessionalLiveTemplateWithCode(context: Context, code: String, userName: String) {
    InteractiveClassUI.enterRoom(context, LPJoinCodeEnterRoomModel(code, userName))
}

/**
 * 专业小班课模板-签名加入
 * @param roomId
 * @param sign
 * @param userInfo
 */
fun startProfessionalLiveTemplateWithSign(
    context: Context,
    roomId: String,
    sign: String,
    userInfo: HashMap<String, Any>
) {
    val lpSignEnterRoomModel = LPSignEnterRoomModel(roomId.toLong(), parseUserModel(userInfo), sign)
    InteractiveClassUI.enterRoom(context, lpSignEnterRoomModel)
}

private fun parseUserModel(userInfo: HashMap<String, Any>): LPUserModel {
    val userModel = LPUserModel()
    userModel.name = userInfo["name"] as String?
    userModel.number = userInfo["number"] as String?
    userModel.type = LPConstants.LPUserType.from(userInfo["type"] as Int? ?: 0)
    userModel.avatar = userInfo["avatar"] as String?
    userModel.groupId = userInfo["groupId"] as Int? ?: 0
    return userModel
}

==> bjy_liveui_flutter-4.2.0.tar.gz: android/src/main/kotlin/com/baijiayun/flutter/bjy_liveui_flutter/LiveUiModule.kt <==
package com.baijiayun.flutter.bjy_liveui_flutter

import android.content.Context
import com.baijiayun.groupclassui.InteractiveClassUI
import com.baijiayun.live.ui.LiveSDKWithUI
import com.baijiayun.livebase.context.LPConstants
import com.baijiayun.livebase.models.LPUserModel
import com.baijiayun.livecore.models.LPJoinCodeEnterRoomModel
import com.baijiayun.livecore.models.LPSignEnterRoomModel
import com.baijiayun.liveshow.ui.LiveShowSDKWithUI
import com.baijiayun.liveuiee.LiveEESDKWithUI

/**
 * 三分屏模板-参加码加入
 * @param code 参加码
 * @param userName 用户名
 */
fun startLiveTripleTemplateWithCode(context: Context, code: String, userName: String) {
    LiveSDKWithUI.enterRoom(context, LPJoinCodeEnterRoomModel(code, userName))
}

/**
 * 三分屏模板-签名加入
 * @param roomId 房间号
 * @param sign   签名
 * @param userInfo 用户信息
 */
fun startLiveTripleTemplateWithSign(
    context: Context,
    roomId: String,
    sign: String,
    userInfo: HashMap<String, Any>
) {
    val lpSignEnterRoomModel = LPSignEnterRoomModel(roomId.toLong(), parseUserModel(userInfo), sign)
    LiveSDKWithUI.enterRoom(context, lpSignEnterRoomModel)
}

/**
 * 竖屏模板-参加码加入
 * @param code
 * @param userName
 */
fun startLiveEETemplateWithCode(context: Context, code: String, userName: String) {
    LiveEESDKWithUI.enterRoom(context, LPJoinCodeEnterRoomModel(code, userName))
}

/**
 * 竖屏模板-签名加入
 * @param roomId
 * @param sign
 * @param userInfo
 */
fun startLiveEETemplateWithSign(
    context: Context,
    roomId: String,
    sign: String,
    userInfo: HashMap<String, Any>
) {
    val lpSignEnterRoomModel = LPSignEnterRoomModel(roomId.toLong(), parseUserModel(userInfo), sign)
    LiveEESDKWithUI.enterRoom(context, lpSignEnterRoomModel)
}

/**
 * 直播带货模板-参加码加入
 * @param code
 * @param userName
 */
fun startLiveSellTemplateWithCode(context: Context, code: String, userName: String) {
    LiveShowSDKWithUI.enterRoom(context, LPJoinCodeEnterRoomModel(code, userName))
}

/**
 * 直播带货模板-签名加入
 * @param roomId
 * @param sign
 * @param userInfo
 */
fun startLiveSellTemplateWithSign(
    context: Context,
    roomId: String,
    sign: String,
    userInfo: HashMap<String, Any>
) {
    val lpSignEnterRoomModel = LPSignEnterRoomModel(roomId.toLong(), parseUserModel(userInfo), sign)
    LiveShowSDKWithUI.enterRoom(context, lpSignEnterRoomModel)
}

/**
 * 专业小班课模板-参加码加入
 * @param code
 * @param userName
 */
fun startProfessionalLiveTemplateWithCode(context: Context, code: String, userName: String) {
    InteractiveClassUI.enterRoom(context, LPJoinCodeEnterRoomModel(code, userName))
}

/**
 * 专业小班课模板-签名加入
 * @param roomId
 * @param sign
 * @param userInfo
 */
fun startProfessionalLiveTemplateWithSign(
    context: Context,
    roomId: String,
    sign: String,
    userInfo: HashMap<String, Any>
) {
    val lpSignEnterRoomModel = LPSignEnterRoomModel(roomId.toLong(), parseUserModel(userInfo), sign)
    InteractiveClassUI.enterRoom(context, lpSignEnterRoomModel)
}

private fun parseUserModel(userInfo: HashMap<String, Any>): LPUserModel {
    val userModel = LPUserModel()
    userModel.name = userInfo["name"] as String?
    userModel.number = userInfo["number"] as String?
    userModel.type = LPConstants.LPUserType.from(userInfo["type"] as Int? ?: 0)
    userModel.avatar = userInfo["avatar"] as String?
    userModel.groupId = userInfo["groupId"] as Int? ?: 0
    return userModel
}
